<template>
    <BasicModal width="800px" :height=600 v-bind="$attrs" @register="register" title="物料列表" @ok="handleSubmit">
      <!-- <div class="pt-3px pr-3px">
        <BasicForm @register="registerForm" :model="model" />
      </div> -->
      <div>
        <BasicTable @register="registerTable">
          <!-- <template #toolbar>
                  <a-button type="primary" @click="handleCreate"> 新增盘点 </a-button>
                </template> -->
        </BasicTable>
      </div>
    </BasicModal>
</template>
<script lang="ts">
import { defineComponent, ref, unref } from 'vue';
import { BasicModal, useModalInner } from '/@/components/Modal';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
import { getTreeList } from '/@/api/tigerapi/dept';
import { BasicTable, TableAction, useTable } from '/@/components/Table';
import { ItemColumns } from './inventory.data';
import { getItemListByPage } from '/@/api/tigerapi/wms/inventory';

const schemas: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    component: 'Input',
    label: '物料编码',
    colProps: {
      span: 12,
    },
  }
];
export default defineComponent({
  components: { BasicModal, BasicForm, BasicTable, TableAction },
  props: {
    userData: { type: Object },
  },
  emit: ['success', 'register'],
  setup(_, { emit }) {
    const modelRef = ref({});
    const [
      registerForm,
      {
        // setFieldsValue,
        // setProps
        updateSchema,
        //validate
      },
    ] = useForm({
      labelWidth: 120,
      schemas,
      showActionButtonGroup: false,
      actionColOptions: {
        span: 24,
      },
    });
    const checkedKeys = ref<Array<string | number>>([]);
    const [registerTable, { reload }] = useTable({
      title: '物料列表',
      api: getItemListByPage,
      columns: ItemColumns,
      formConfig: {
        labelWidth: 120,
        schemas
      },
      useSearchForm: true,
      showTableSetting: true,
      rowKey: 'ITEM_CODE',
      rowSelection: {
        selectedRowKeys: checkedKeys,
        
        type: 'checkbox',
        // getCheckboxProps(record: Recordable) {
        //   // Demo: 第一行（id为0）的选择框禁用
        //   if (record.id === '0') {
        //     return { disabled: true };
        //   } else {
        //     return { disabled: false };
        //   }
        // },
        onSelect: onSelect,
        onSelectAll: onSelectAll,
      },
      //bordered: true,
      showIndexColumn: false,
      // actionColumn: {
      //   width: 80,
      //   title: '操作',
      //   dataIndex: 'action',
      //   slots: { customRender: 'action' },
      //   fixed: 'right' //undefined,
      // },
    });
    const [register, { setModalProps, closeModal }] = useModalInner((data) => {
      setModalProps({ confirmLoading: false });
      data && onDataReceive(data);
    });

    async function onDataReceive(data) {
      console.log('Data Received', data);
      // 方式1;
      // setFieldsValue({
      //   field2: data.data,
      //   field1: data.info,
      // });

      // // 方式2
      modelRef.value = { field2: data.data, field1: data.info };
      const treeData = await getTreeList();
      updateSchema([
        {
          field: 'USER_PWD',
          show: !unref(false),
        },
        {
          field: 'ORG_CODE',
          componentProps: { treeData },
        },
      ]);
      // setProps({
      //   model:{ field2: data.data, field1: data.info }
      // })
    }

    // function handleVisibleChange(v) {
    //   v && props.userData && nextTick(() => onDataReceive(props.userData));
    // }

    async function handleSubmit() {
      try {

        var values = '';
        // checkedKeys.value.forEach(element => {
        //   values+=element;
        // });
        values=checkedKeys.value.join(',')
        closeModal();
        emit('success', {
          isUpdate: unref(false),
          values: { values, id: 0 },
        });

      } finally {
        setModalProps({ confirmLoading: false });
      }
    }
    function onSelect(record, selected) {
        if (selected) {
          checkedKeys.value = [...checkedKeys.value, record.ITEM_CODE];
        } else {
          checkedKeys.value = checkedKeys.value.filter((ITEM_CODE) => ITEM_CODE !== record.ITEM_CODE);
        }
      }
      function onSelectAll(selected, selectedRows, changeRows) {
        const changeIds = changeRows.map((item) => item.ITEM_CODE);
        if (selected) {
          checkedKeys.value = [...checkedKeys.value, ...changeIds];
        } else {
          checkedKeys.value = checkedKeys.value.filter((ITEM_CODE) => {
            return !changeIds.includes(ITEM_CODE);
          });
        }
      }

    return { 
      register, 
      schemas, 
      registerForm, 
      model: modelRef, 
      handleSubmit, 
      registerTable,
      onSelect,
      onSelectAll
    };
  },
});
</script>
